@@ -653,8 +653,16 @@ void qjackctlConnectorView::drawConnectionLine ( QPainter& p, int x1, int y1, in
     if (y1 > h1)
         p.drawLine(x1, y1, x1 + 4, y1);
 
-    // The connection line, it self.
-    p.drawLine(x1 + 4, y1, x2 - 4, y2);
+    // How do we'll draw it?
+    if (m_pConnectView->isBezierLines()) {
+        // Setup control points
+        QPointArray spline(4);
+        int cp = (int)((double)(x2 - x1 - 8) * 0.4);
+        spline.putPoints(0, 4, x1 + 4, y1, x1 + 4 + cp, y1, x2 - 4 - cp, y2, x2 - 4, y2);
+        // The connection line, it self.
+        p.drawCubicBezier(spline);
+    }
+    else p.drawLine(x1 + 4, y1, x2 - 4, y2);
 
     // Invisible input ports don't get a connecting dot.
     if (y2 > h2)
@@ -669,10 +677,10 @@ void qjackctlConnectorView::drawConnections (void)
         return;
     
     QPainter p(this);
-    QRect r1, r2;
-    int   x1, y1, h1;
-    int   x2, y2, h2;
-    int   i, c, rgb[3];
+    int x1, y1, h1;
+    int x2, y2, h2;
+    int i, c, rgb[3];
+    int w;
 
     // Initialize color changer.
     i = c = rgb[0] = rgb[1] = rgb[2] = 0;
@@ -681,6 +689,10 @@ void qjackctlConnectorView::drawConnections (void)
     x2 = width();
     h1 = ((m_pConnectView->OListView())->header())->sectionRect(0).height();
     h2 = ((m_pConnectView->IListView())->header())->sectionRect(0).height();
+    // about some specialty line width...
+    w = m_pConnectView->iconSize();
+    if (w < 2)
+        w = 0;
     // For each client item...
     for (qjackctlClientItem *pOClient = m_pConnectView->OClientList()->clients().first();
             pOClient;
@@ -689,7 +701,7 @@ void qjackctlConnectorView::drawConnections (void)
         c += 0x39;
         c &= 0xff;
         rgb[i++] = c;
-        p.setPen(QColor(rgb[2], rgb[1], rgb[0]));
+        p.setPen(QPen(QColor(rgb[2], rgb[1], rgb[0]), w));
         if (i > 2)
             i = 0;
         // For each port item
@@ -697,23 +709,27 @@ void qjackctlConnectorView::drawConnections (void)
                 pOPort;
                     pOPort = pOClient->ports().next()) {
             // Get starting connector arrow coordinates.
-            r1 = (m_pConnectView->OListView())->itemRect(pOPort);
-            y1 = (r1.top() + r1.bottom()) / 2;
-            // If this item is not visible, don't bother to update it.
-            if (!pOPort->isVisible() || y1 < 1) {
-                r1 = (m_pConnectView->OListView())->itemRect(pOClient);
-                y1 = (r1.top() + r1.bottom()) / 2;
+            QListViewItem* pOParent = pOPort->parent();
+            if (pOParent == 0 || pOParent->isOpen()) {
+                y1 = (m_pConnectView->OListView())->itemPos(pOPort) + 
+                     pOPort->height() / 2 - (m_pConnectView->OListView())->contentsY();
+            } else {
+                y1 = (m_pConnectView->OListView())->itemPos(pOParent) + 
+                     pOParent->height() / 2 - (m_pConnectView->OListView())->contentsY();
             }
+            
             // Get port connections...
             for (qjackctlPortItem *pIPort = pOPort->connects().first();
                     pIPort;
                         pIPort = pOPort->connects().next()) {
                 // Obviously, there is a connection from pOPort to pIPort items:
-                r2 = (m_pConnectView->IListView())->itemRect(pIPort);
-                y2 = (r2.top() + r2.bottom()) / 2;
-                if (!pIPort->isVisible() || y2 < 1) {
-                    r2 = (m_pConnectView->IListView())->itemRect(pIPort->client());
-                    y2 = (r2.top() + r2.bottom()) / 2;
+                QListViewItem* pIParent = pIPort->parent();
+                if (pIParent == 0 || pIParent->isOpen()) {
+                    y2 = (m_pConnectView->IListView())->itemPos(pIPort) + 
+                         pIPort->height() / 2 - (m_pConnectView->IListView())->contentsY();
+                } else {
+                    y2 = (m_pConnectView->IListView())->itemPos(pIParent) + 
+                        pIParent->height() / 2 - (m_pConnectView->IListView())->contentsY();
                 }
                 drawConnectionLine(p, x1, y1, x2, y2, h1, h2);
             }
@@ -769,7 +785,10 @@ qjackctlConnectView::qjackctlConnectView ( QWidget *pParent, const char *pszName
     m_pIListView     = new qjackctlClientListView(this, false);
 
     m_pConnect = 0;
-
+    
+    m_bBezierLines = false;
+    m_iIconSize    = 0;
+    
     QObject::connect(m_pOListView, SIGNAL(expanded(QListViewItem *)),  m_pConnectorView, SLOT(listViewChanged(QListViewItem *)));
     QObject::connect(m_pOListView, SIGNAL(collapsed(QListViewItem *)), m_pConnectorView, SLOT(listViewChanged(QListViewItem *)));
     QObject::connect(m_pOListView, SIGNAL(contentsMoving(int, int)),   m_pConnectorView, SLOT(contentsMoved(int, int)));
@@ -846,6 +865,40 @@ qjackctlClientList *qjackctlConnectView::IClientList (void)
 }
 
 
+// Connector line style accessors.
+void qjackctlConnectView::setBezierLines ( bool bBezierLines )
+{
+    m_bBezierLines = bBezierLines;
+}
+
+bool qjackctlConnectView::isBezierLines (void)
+{
+    return m_bBezierLines;
+}
+
+
+// Common icon size methods.
+void qjackctlConnectView::setIconSize ( int iIconSize )
+{
+    // Update only if changed.
+    if (iIconSize == m_iIconSize)
+        return;
+
+    // Go for it...
+    m_iIconSize = iIconSize;
+
+    // Call binding descendant implementation,
+    // and do a complete content reset...
+    if (m_pConnect)
+        m_pConnect->updateContents(true);
+}
+
+int qjackctlConnectView::iconSize (void)
+{
+    return m_iIconSize;
+}
+
+
 //----------------------------------------------------------------------
 // qjackctlConnect -- Output-to-Input client/ports connection object.
 //
@@ -1272,12 +1325,19 @@ bool qjackctlConnect::disconnectAllEx (void)
 }
 
 
-// Complete contents rebuilder; return dirty status.
-void qjackctlConnect::refresh (void)
+// Complete/incremental contents rebuilder; check dirty status if incremental.
+void qjackctlConnect::updateContents ( bool bClear )
 {
     int iDirtyCount = 0;
 
     if (startMutex()) {
+        // Do we do a complete rebuild?
+        if (bClear) {
+            (m_pOClientList->listView())->clear();
+            (m_pIClientList->listView())->clear();
+            updateIconPixmaps();
+        }
+        // Add (newer) client:ports and respective connections...
         iDirtyCount += m_pOClientList->updateClientPorts();
         iDirtyCount += m_pIClientList->updateClientPorts();
         updateConnections();
@@ -1286,11 +1346,18 @@ void qjackctlConnect::refresh (void)
 
     (m_pConnectView->ConnectorView())->update();
 
-    if (iDirtyCount > 0)
+    if (!bClear && iDirtyCount > 0)
         emit connectChanged();
 }
 
 
+// Incremental contents rebuilder; check dirty status.
+void qjackctlConnect::refresh (void)
+{
+    updateContents(false);
+}
+
+
 // Dunno. But this may avoid some conflicts.
 bool qjackctlConnect::startMutex (void)
 {
@@ -1318,5 +1385,19 @@ qjackctlClientList *qjackctlConnect::IClientList (void)
     return m_pIClientList;
 }
 
+
+// Common pixmap factory-method.
+QPixmap *qjackctlConnect::createIconPixmap ( const QString& sIconName )
+{
+    QString sName = sIconName;
+    int     iSize = m_pConnectView->iconSize() * 32;
+
+    if (iSize > 0)
+        sName += QString("_%1x%2").arg(iSize).arg(iSize);
+
+    return new QPixmap(QPixmap::fromMimeSource(sName + ".png"));
+}
+
+
 // end of qjackctlConnect.cpp
 
