@@ -333,6 +333,14 @@ public:
     qjackctlClientList *OClientList();
     qjackctlClientList *IClientList();
 
+    // Connector line style accessors.
+    void setBezierLines(bool bBezierLines);
+    bool isBezierLines();
+    
+    // Common icon size pixmap accessors.
+    void setIconSize (int iIconSize);
+    int iconSize (void);
+
 public slots:
 
     // Common context menu slot.
@@ -347,6 +355,13 @@ private:
 
     // The main binding object.
     qjackctlConnect *m_pConnect;
+    
+    // How we'll draw connector lines.
+    bool m_bBezierLines;
+
+    // How large will be those icons.
+    // 0 = 16x16 (default), 1 = 32x32, 2 = 64x64.
+    int m_iIconSize;
 };
 
 
@@ -375,7 +390,7 @@ public:
 
 public slots:
 
-    // Complete contents refreshner; return dirty status.
+    // Incremental contents refreshner; check dirty status.
     void refresh();
 
     // Explicit connection slots.
@@ -383,6 +398,9 @@ public slots:
     bool disconnectSelected();
     bool disconnectAll();
 
+    // Complete/incremental contents rebuilder; check dirty status if incremental.
+    void updateContents (bool bClear);
+
 signals:
 
     // Connection change signal.
@@ -402,12 +420,18 @@ protected:
     void setOClientList(qjackctlClientList *pOClientList);
     void setIClientList(qjackctlClientList *pIClientList);
     
+    // Common pixmap factory helper-method.
+    QPixmap *createIconPixmap (const QString& sIconName);
+
+    // Update icon size implementation.
+    virtual void updateIconPixmaps() = 0;
+    
 private:
 
     // Dunno. But this may avoid some conflicts.
     bool startMutex();
     void endMutex();
-
+    
     // Connection methods (unguarded).
     bool canConnectSelectedEx();
     bool canDisconnectSelectedEx();
