@@ -33,22 +33,6 @@
 // External patchbay loader.
 #include "qjackctlPatchbayFile.h"
 
-
-// Common socket pixmap overlays.
-#include "icons/xsocket1.xpm"
-
-// Audio socket/plug pixmaps.
-#include "icons/asocketo.xpm"
-#include "icons/asocketi.xpm"
-#include "icons/aplugo.xpm"
-#include "icons/aplugi.xpm"
-
-// MIDI socket/plug pixmaps.
-#include "icons/msocketi.xpm"
-#include "icons/msocketo.xpm"
-#include "icons/mplugo.xpm"
-#include "icons/mplugi.xpm"
-
 // Common pixmap resources.
 static int      g_iXpmRefCount = 0;
 // Exclusive socket overlay pixmap.
@@ -299,7 +283,7 @@ void qjackctlSocketItem::updatePixmap (void)
 qjackctlSocketList::qjackctlSocketList( qjackctlSocketListView *pListView, bool bReadable )
 {
     if (g_iXpmRefCount == 0) {
-        g_pXpmXSocket1 = new QPixmap((const char **) xsocket1_xpm);
+        g_pXpmXSocket1 = new QPixmap(QPixmap::fromMimeSource("xsocket1.png"));
     }
     g_iXpmRefCount++;
 
@@ -310,20 +294,20 @@ qjackctlSocketList::qjackctlSocketList( qjackctlSocketListView *pListView, bool
     
     if (bReadable) {
         m_sSocketCaption = tr("Output");
-        m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET]   = new QPixmap((const char **) asocketo_xpm);
+        m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET]   = new QPixmap(QPixmap::fromMimeSource("asocketo.png"));
         m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET_X] = createPixmapMerge(*m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET], *g_pXpmXSocket1);
-        m_apPixmaps[QJACKCTL_XPM_AUDIO_PLUG]     = new QPixmap((const char **) aplugo_xpm);
-        m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET]    = new QPixmap((const char **) msocketo_xpm);
+        m_apPixmaps[QJACKCTL_XPM_AUDIO_PLUG]     = new QPixmap(QPixmap::fromMimeSource("aportlno.png"));
+        m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET]    = new QPixmap(QPixmap::fromMimeSource("msocketo.png"));
         m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET_X]  = createPixmapMerge(*m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET], *g_pXpmXSocket1);
-        m_apPixmaps[QJACKCTL_XPM_MIDI_PLUG]      = new QPixmap((const char **) mplugo_xpm);
+        m_apPixmaps[QJACKCTL_XPM_MIDI_PLUG]      = new QPixmap(QPixmap::fromMimeSource("mporto.png"));
     } else {
         m_sSocketCaption = tr("Input");
-        m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET]   = new QPixmap((const char **) asocketi_xpm);
+        m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET]   = new QPixmap(QPixmap::fromMimeSource("asocketi.png"));
         m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET_X] = createPixmapMerge(*m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET], *g_pXpmXSocket1);
-        m_apPixmaps[QJACKCTL_XPM_AUDIO_PLUG]     = new QPixmap((const char **) aplugi_xpm);
-        m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET]    = new QPixmap((const char **) msocketi_xpm);
+        m_apPixmaps[QJACKCTL_XPM_AUDIO_PLUG]     = new QPixmap(QPixmap::fromMimeSource("aportlni.png"));
+        m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET]    = new QPixmap(QPixmap::fromMimeSource("msocketi.png"));
         m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET_X]  = createPixmapMerge(*m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET], *g_pXpmXSocket1);
-        m_apPixmaps[QJACKCTL_XPM_MIDI_PLUG]      = new QPixmap((const char **) mplugi_xpm);
+        m_apPixmaps[QJACKCTL_XPM_MIDI_PLUG]      = new QPixmap(QPixmap::fromMimeSource("mporti.png"));
     }
 
     if (!m_sSocketCaption.isEmpty())
@@ -988,8 +972,16 @@ void qjackctlPatchworkView::drawConnectionLine ( QPainter& p, int x1, int y1, in
     if (y1 > h1)
         p.drawLine(x1, y1, x1 + 4, y1);
 
-    // The connection line, it self.
-    p.drawLine(x1 + 4, y1, x2 - 4, y2);
+    // How do we'll draw it?
+    if (m_pPatchbayView->isBezierLines()) {
+        // Setup control points
+        QPointArray spline(4);
+        int cp = (int)((double)(x2 - x1 - 8) * 0.4);
+        spline.putPoints(0, 4, x1 + 4, y1, x1 + 4 + cp, y1, x2 - 4 - cp, y2, x2 - 4, y2);
+        // The connection line, it self.
+        p.drawCubicBezier(spline);
+    }   // Old style...
+    else p.drawLine(x1 + 4, y1, x2 - 4, y2);
 
     // Invisible input plugs don't get a connecting dot.
     if (y2 > h2)
@@ -1004,7 +996,6 @@ void qjackctlPatchworkView::drawConnections (void)
         return;
     
     QPainter p(this);
-    QRect r1, r2;
     int   x1, y1, h1;
     int   x2, y2, h2;
     int   i, c, rgb[3];
@@ -1028,15 +1019,27 @@ void qjackctlPatchworkView::drawConnections (void)
         if (i > 2)
             i = 0;
         // Get starting connector arrow coordinates.
-        r1 = (m_pPatchbayView->OListView())->itemRect(pOSocket);
-        y1 = (r1.top() + r1.bottom()) / 2;
+        QListViewItem* pOParent = pOSocket->parent();
+        if (pOParent == 0 || pOParent->isOpen()) {
+            y1 = (m_pPatchbayView->OListView())->itemPos(pOSocket) + 
+                 pOSocket->height() / 2 - (m_pPatchbayView->OListView())->contentsY();
+        } else {
+            y1 = (m_pPatchbayView->OListView())->itemPos(pOParent) + 
+                 pOParent->height() / 2 - (m_pPatchbayView->OListView())->contentsY();
+        }
         // Get input socket connections...
         for (qjackctlSocketItem *pISocket = pOSocket->connects().first();
                 pISocket;
                     pISocket = pOSocket->connects().next()) {
             // Obviously, there is a connection from pOPlug to pIPlug items:
-            r2 = (m_pPatchbayView->IListView())->itemRect(pISocket);
-            y2 = (r2.top() + r2.bottom()) / 2;
+            QListViewItem* pIParent = pISocket->parent();
+            if (pIParent == 0 || pIParent->isOpen()) {
+                y2 = (m_pPatchbayView->IListView())->itemPos(pISocket) + 
+                      pISocket->height() / 2 - (m_pPatchbayView->IListView())->contentsY();
+            } else {
+                y2 = (m_pPatchbayView->IListView())->itemPos(pIParent) + 
+                      pIParent->height() / 2 - (m_pPatchbayView->IListView())->contentsY();
+            }
             drawConnectionLine(p, x1, y1, x2, y2, h1, h2);
         }
     }
@@ -1091,6 +1094,8 @@ qjackctlPatchbayView::qjackctlPatchbayView ( QWidget *pParent, const char *pszNa
 
     m_pPatchbay = 0;
 
+    m_bBezierLines = false;
+
     QObject::connect(m_pOListView, SIGNAL(currentChanged(QListViewItem *)), m_pPatchworkView, SLOT(listViewChanged(QListViewItem *)));
     QObject::connect(m_pOListView, SIGNAL(expanded(QListViewItem *)),  m_pPatchworkView, SLOT(listViewChanged(QListViewItem *)));
     QObject::connect(m_pOListView, SIGNAL(collapsed(QListViewItem *)), m_pPatchworkView, SLOT(listViewChanged(QListViewItem *)));
@@ -1191,6 +1196,18 @@ qjackctlSocketList *qjackctlPatchbayView::ISocketList (void)
 }
 
 
+// Patchwork line style accessors.
+void qjackctlPatchbayView::setBezierLines ( bool bBezierLines )
+{
+    m_bBezierLines = bBezierLines;
+}
+
+bool qjackctlPatchbayView::isBezierLines (void)
+{
+    return m_bBezierLines;
+}
+
+
 // Dirty flag methods.
 void qjackctlPatchbayView::setDirty ( bool bDirty )
 {
