@@ -44,33 +44,39 @@ qjackctlSetup::qjackctlSetup (void)
     m_settings.endGroup();
 
     m_settings.beginGroup("/Options");
-    bStartJack              = m_settings.readBoolEntry("/StartJack", false);
-    bStartupScript          = m_settings.readBoolEntry("/StartupScript", true);
-    sStartupScriptShell     = m_settings.readEntry("/StartupScriptShell", "artsshell -q terminate");
-    bPostStartupScript      = m_settings.readBoolEntry("/PostStartupScript", false);
-    sPostStartupScriptShell = m_settings.readEntry("/PostStartupScriptShell", QString::null);
-    bShutdownScript         = m_settings.readBoolEntry("/ShutdownScript", false);
-    sShutdownScriptShell    = m_settings.readEntry("/ShutdownScriptShell", QString::null);
-    bStdoutCapture          = m_settings.readBoolEntry("/StdoutCapture", true);
-    sXrunRegex              = m_settings.readEntry("/XrunRegex", "xrun of at least ([0-9|\\.]+) msecs");
-    bXrunIgnoreFirst        = m_settings.readBoolEntry("/XrunIgnoreFirst", false);
-    bActivePatchbay         = m_settings.readBoolEntry("/ActivePatchbay", false);
-    sActivePatchbayPath     = m_settings.readEntry("/ActivePatchbayPath", QString::null);
-    bAutoRefresh            = m_settings.readBoolEntry("/AutoRefresh", false);
-    iTimeRefresh            = m_settings.readNumEntry("/TimeRefresh", 10);
-    iTimeDisplay            = m_settings.readNumEntry("/TimeDisplay", 0);
-    iTimeFormat             = m_settings.readNumEntry("/TimeFormat", 0);
-    sMessagesFont           = m_settings.readEntry("/MessagesFont", QString::null);
-    bMessagesLimit          = m_settings.readBoolEntry("/MessagesLimit", true);
-    iMessagesLimitLines     = m_settings.readNumEntry("/MessagesLimitLines", 1000);
-    sDisplayFont1           = m_settings.readEntry("/DisplayFont1", QString::null);
-    sDisplayFont2           = m_settings.readEntry("/DisplayFont2", QString::null);
-    bQueryClose             = m_settings.readBoolEntry("/QueryClose", true);
-    bKeepOnTop              = m_settings.readBoolEntry("/KeepOnTop", true);
-    bSystemTray             = m_settings.readBoolEntry("/SystemTray", false);
-    bServerConfig           = m_settings.readBoolEntry("/ServerConfig", true);
-    sServerConfigName       = m_settings.readEntry("/ServerConfigName", ".jackdrc");
-    bServerConfigTemp       = m_settings.readBoolEntry("/ServerConfigTemp", false);
+    bStartJack               = m_settings.readBoolEntry("/StartJack", false);
+    bStartupScript           = m_settings.readBoolEntry("/StartupScript", true);
+    sStartupScriptShell      = m_settings.readEntry("/StartupScriptShell", "artsshell -q terminate");
+    bPostStartupScript       = m_settings.readBoolEntry("/PostStartupScript", false);
+    sPostStartupScriptShell  = m_settings.readEntry("/PostStartupScriptShell", QString::null);
+    bShutdownScript          = m_settings.readBoolEntry("/ShutdownScript", false);
+    sShutdownScriptShell     = m_settings.readEntry("/ShutdownScriptShell", QString::null);
+    bPostShutdownScript      = m_settings.readBoolEntry("/PostShutdownScript", false);
+    sPostShutdownScriptShell = m_settings.readEntry("/PostShutdownScriptShell", QString::null);
+    bStdoutCapture           = m_settings.readBoolEntry("/StdoutCapture", true);
+    sXrunRegex               = m_settings.readEntry("/XrunRegex", "xrun of at least ([0-9|\\.]+) msecs");
+    bXrunIgnoreFirst         = m_settings.readBoolEntry("/XrunIgnoreFirst", false);
+    bActivePatchbay          = m_settings.readBoolEntry("/ActivePatchbay", false);
+    sActivePatchbayPath      = m_settings.readEntry("/ActivePatchbayPath", QString::null);
+    bAutoRefresh             = m_settings.readBoolEntry("/AutoRefresh", false);
+    iTimeRefresh             = m_settings.readNumEntry("/TimeRefresh", 10);
+    bBezierLines             = m_settings.readBoolEntry("/BezierLines", false);
+    iTimeDisplay             = m_settings.readNumEntry("/TimeDisplay", 0);
+    iTimeFormat              = m_settings.readNumEntry("/TimeFormat", 0);
+    sMessagesFont            = m_settings.readEntry("/MessagesFont", QString::null);
+    bMessagesLimit           = m_settings.readBoolEntry("/MessagesLimit", true);
+    iMessagesLimitLines      = m_settings.readNumEntry("/MessagesLimitLines", 1000);
+    sDisplayFont1            = m_settings.readEntry("/DisplayFont1", QString::null);
+    sDisplayFont2            = m_settings.readEntry("/DisplayFont2", QString::null);
+    bDisplayEffect           = m_settings.readBoolEntry("/DisplayEffect", true);
+    iConnectionsIconSize     = m_settings.readNumEntry("/ConnectionsIconSize", QJACKCTL_ICON_16X16);
+    sConnectionsFont         = m_settings.readEntry("/ConnectionsFont", QString::null);
+    bQueryClose              = m_settings.readBoolEntry("/QueryClose", true);
+    bKeepOnTop               = m_settings.readBoolEntry("/KeepOnTop", true);
+    bSystemTray              = m_settings.readBoolEntry("/SystemTray", false);
+    bServerConfig            = m_settings.readBoolEntry("/ServerConfig", true);
+    sServerConfigName        = m_settings.readEntry("/ServerConfigName", ".jackdrc");
+    bServerConfigTemp        = m_settings.readBoolEntry("/ServerConfigTemp", false);
     m_settings.endGroup();
 
     m_settings.beginGroup("/Defaults");
@@ -107,6 +113,8 @@ qjackctlSetup::~qjackctlSetup (void)
     m_settings.writeEntry("/PostStartupScriptShell",  sPostStartupScriptShell);
     m_settings.writeEntry("/ShutdownScript",          bShutdownScript);
     m_settings.writeEntry("/ShutdownScriptShell",     sShutdownScriptShell);
+    m_settings.writeEntry("/PostShutdownScript",      bPostShutdownScript);
+    m_settings.writeEntry("/PostShutdownScriptShell", sPostShutdownScriptShell);
     m_settings.writeEntry("/StdoutCapture",           bStdoutCapture);
     m_settings.writeEntry("/XrunRegex",               sXrunRegex);
     m_settings.writeEntry("/XrunIgnoreFirst",         bXrunIgnoreFirst);
@@ -114,6 +122,7 @@ qjackctlSetup::~qjackctlSetup (void)
     m_settings.writeEntry("/ActivePatchbayPath",      sActivePatchbayPath);
     m_settings.writeEntry("/AutoRefresh",             bAutoRefresh);
     m_settings.writeEntry("/TimeRefresh",             iTimeRefresh);
+    m_settings.writeEntry("/BezierLines",             bBezierLines);
     m_settings.writeEntry("/TimeDisplay",             iTimeDisplay);
     m_settings.writeEntry("/TimeFormat",              iTimeFormat);
     m_settings.writeEntry("/MessagesFont",            sMessagesFont);
@@ -121,6 +130,9 @@ qjackctlSetup::~qjackctlSetup (void)
     m_settings.writeEntry("/MessagesLimitLines",      iMessagesLimitLines);
     m_settings.writeEntry("/DisplayFont1",            sDisplayFont1);
     m_settings.writeEntry("/DisplayFont2",            sDisplayFont2);
+    m_settings.writeEntry("/DisplayEffect",           bDisplayEffect);
+    m_settings.writeEntry("/ConnectionsIconSize",     iConnectionsIconSize);
+    m_settings.writeEntry("/ConnectionsFont",         sConnectionsFont);
     m_settings.writeEntry("/QueryClose",              bQueryClose);
     m_settings.writeEntry("/KeepOnTop",               bKeepOnTop);
     m_settings.writeEntry("/SystemTray",              bSystemTray);
