@@ -31,6 +31,11 @@
 #define QJACKCTL_CAPTURE    1
 #define QJACKCTL_PLAYBACK   2
 
+// Icon size combobox item indexes.
+#define QJACKCTL_ICON_16X16 0
+#define QJACKCTL_ICON_32X32 1
+#define QJACKCTL_ICON_64X64 2
+
 
 // Server settings preset struct.
 struct qjackctlPreset
@@ -101,6 +106,8 @@ public:
     QString sPostStartupScriptShell;
     bool    bShutdownScript;
     QString sShutdownScriptShell;
+    bool    bPostShutdownScript;
+    QString sPostShutdownScriptShell;
     bool    bStdoutCapture;
     QString sXrunRegex;
     bool    bXrunIgnoreFirst;
@@ -108,6 +115,7 @@ public:
     QString sActivePatchbayPath;
     bool    bAutoRefresh;
     int     iTimeRefresh;
+    bool    bBezierLines;
     int     iTimeDisplay;
     int     iTimeFormat;
     QString sMessagesFont;
@@ -115,6 +123,9 @@ public:
     int     iMessagesLimitLines;
     QString sDisplayFont1;
     QString sDisplayFont2;
+    bool    bDisplayEffect;
+    int     iConnectionsIconSize;
+    QString sConnectionsFont;
     bool    bQueryClose;
     bool    bKeepOnTop;
     bool    bSystemTray;
